@@ -1,4 +1,4 @@
-#include "perly-5.31.5.h"
+#include "perly-5.29.10.h"
 enum token_type {
     TOKENTYPE_NONE,
     TOKENTYPE_IVAL,
@@ -77,8 +77,6 @@ static struct debug_tokens {
     { SHIFTOP,		TOKENTYPE_OPNUM,	"SHIFTOP" },
     { SIGSUB,		TOKENTYPE_NONE,		"SIGSUB" },
     { SUB,		TOKENTYPE_NONE,		"SUB" },
-    { SUBLEXEND,	TOKENTYPE_NONE,		"SUBLEXEND" },
-    { SUBLEXSTART,	TOKENTYPE_NONE,		"SUBLEXSTART" },
     { THING,		TOKENTYPE_OPVAL,	"THING" },
     { UMINUS,		TOKENTYPE_NONE,		"UMINUS" },
     { UNIOP,		TOKENTYPE_OPNUM,	"UNIOP" },
@@ -97,7 +95,6 @@ static struct debug_tokens {
     { GRAMBARESTMT, TOKENTYPE_OPNUM, "GRAMBARESTMT" },
     { GRAMFULLSTMT, TOKENTYPE_OPNUM, "GRAMFULLSTMT" },
     { GRAMSTMTSEQ, TOKENTYPE_OPNUM, "GRAMSTMTSEQ" },
-    { GRAMSUBSIGNATURE, TOKENTYPE_OPNUM, "GRAMSUBSIGNATURE" },
     { PREC_LOW, TOKENTYPE_OPNUM, "PREC_LOW" },
     { 0,		TOKENTYPE_NONE,		NULL }
 };
