@@ -388,13 +388,67 @@
 #include "token_info-5.33.7.h"
 #elif PERL_VERSION == 34 && PERL_SUBVERSION == 0
 #include "token_info-5.34.0.h"
+#elif PERL_VERSION == 34 && PERL_SUBVERSION == 1
+#include "token_info-5.34.0.h"
 #elif PERL_VERSION == 34
 #include "token_info-5.34.0.h"
 #elif PERL_VERSION == 35 && PERL_SUBVERSION == 0
 #include "token_info-5.35.0.h"
 #elif PERL_VERSION == 35 && PERL_SUBVERSION == 1
 #include "token_info-5.35.1.h"
-#elif PERL_VERSION > 35 || (PERL_VERSION == 35 && PERL_SUBVERSION > 1)
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 2
+#include "token_info-5.35.1.h"
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 3
+#include "token_info-5.35.1.h"
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 4
+#include "token_info-5.35.4.h"
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 5
+#include "token_info-5.35.4.h"
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 6
+#include "token_info-5.35.4.h"
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 7
+#include "token_info-5.35.4.h"
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 8
+#include "token_info-5.35.8.h"
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 9
+#include "token_info-5.35.8.h"
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 10
+#include "token_info-5.35.8.h"
+#elif PERL_VERSION == 35 && PERL_SUBVERSION == 11
+#include "token_info-5.35.11.h"
+#elif PERL_VERSION == 36 && PERL_SUBVERSION == 0
+#include "token_info-5.36.0.h"
+#elif PERL_VERSION == 36 && PERL_SUBVERSION == 1
+#include "token_info-5.36.0.h"
+#elif PERL_VERSION == 36
+#include "token_info-5.36.0.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 0
+#include "token_info-5.37.0.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 1
+#include "token_info-5.37.1.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 2
+#include "token_info-5.37.2.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 3
+#include "token_info-5.37.2.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 4
+#include "token_info-5.37.2.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 5
+#include "token_info-5.37.2.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 6
+#include "token_info-5.37.6.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 7
+#include "token_info-5.37.7.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 8
+#include "token_info-5.37.7.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 9
+#include "token_info-5.37.9.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 10
+#include "token_info-5.37.10.h"
+#elif PERL_VERSION == 37 && PERL_SUBVERSION == 11
+#include "token_info-5.37.10.h"
+#elif PERL_VERSION == 38 && PERL_SUBVERSION == 0
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION > 38 || (PERL_VERSION == 38 && PERL_SUBVERSION > 0)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
